@@ -726,7 +726,8 @@ class ServiceInstanceManager(object):
 
 class BaseNetworkhelper(metaclass=abc.ABCMeta):
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def NAME(self):
         """Returns code name of network helper."""
 
@@ -892,7 +893,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 network_data['service_subnet'] = (
                     self.neutron_api.subnet_create(
                         self.admin_project_id, self.service_network_id,
-                        subnet_name, self._get_cidr_for_subnet()))
+                        subnet_name, self._get_cidr_for_subnet(),
+                        self.connect_share_server_to_tenant_network))
 
         network_data['ports'] = []
 
@@ -1013,7 +1015,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
 
         This port will be used for connectivity with service instances.
         """
-        host = socket.gethostname()
+        host = CONF.host
         search_opts = {'device_id': device_id,
                        'binding:host_id': host}
         ports = [port for port in self.neutron_api.
